@@ -7,7 +7,7 @@ require Carp;
 require Scalar::Util;
 use File::Spec ();
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 our $LEADING_SPACE  = qr/(?:\n [ ]*)?/x;
 our $TRAILING_SPACE = qr/(?:[ ]* \n)?/x;
@@ -374,9 +374,14 @@ sub _parse_partial {
         $template = "$template.$ext";
     }
 
+    my $parse = 1;
+    if ($template =~ s{^\&}{}) {
+        $parse = 0;
+    }
+
     my $content = $self->_slurp_template($template);
 
-    return $self->_parse($content, $context);
+    return $parse ? $self->_parse($content, $context) : $content;
 }
 
 sub _parse_inherited_template {
@@ -624,6 +629,12 @@ current context and can be recursive.
     {{>article_summary}}
     {{/articles}}
 
+If you want to include another file without parsing, prefix the filename with C<&>:
+
+    {{#articles}}
+    {{>&article_summary_not_parsed}}
+    {{/articles}}
+
 =head3 Nested Templates
 
 This gives horgan.js style template inheritance.
